Flask-API-Framework
===================

Framework for building semantically correct HTTP API's in Flask.

|GitHub tests| |Documentation Status|
|PyPI version| |PyPI pyversions| |PyPI license|


Installing
----------

Install package from PyPI.

.. code-block:: text

    pip install Flask-API-Framework


Links
-----

- Documentation_
- PyPI_
- Source_

.. _Documentation: https://flask-api-framework.readthedocs.io/
.. _PyPI: https://pypi.org/project/Flask-API-Framework/
.. _Source: https://github.com/thnee/flask-api-framework


.. |GitHub tests| image:: https://github.com/thnee/flask-api-framework/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/thnee/flask-api-framework/actions

.. |Documentation Status| image:: https://readthedocs.org/projects/flask-api-framework/badge/?version=latest
   :target: https://flask-api-framework.readthedocs.io/en/latest/

.. |PyPI version| image:: https://img.shields.io/pypi/v/Flask-API-Framework?color=1283c4&label=version
   :target: https://pypi.org/project/Flask-API-Framework/

.. |PyPI pyversions| image:: https://img.shields.io/pypi/pyversions/Flask-API-Framework.svg
   :target: https://pypi.org/project/Flask-API-Framework/

.. |PyPI license| image:: https://img.shields.io/pypi/l/Flask-API-Framework.svg
   :target: https://pypi.org/project/Flask-API-Framework/
